<?php
class myThemes{

    /* READ ADMIN SETTINGS */
    static function get( $optName , $strip = false )
    {
        return sett::get( 'mythemes-' . $optName , $strip );
    }

    static function pget( $optName )
    {
        if( isset( $_POST ) && isset( $_POST[ 'mythemes-' . $optName ] ) )
            return $_POST[ 'mythemes-' . $optName ];
        else
            return self::get( $optName );
    }

    /* READ THEME SETTINGS */
    static function cfg( $sett )
    {
        $result = '';
        $file = get_template_directory() . '/cfg/static.php';

        if( file_exists( $file ) ){
            include $file;

            if( isset( $cfg[ $sett ] ) ){
                $result = $cfg[ $sett ];
            }
        }

        return $result;
    }


    /* INIT FILTERS */
    static function init_filters()
    {
        $filters = self::cfg( 'filters' );
        if( !empty( $filters ) && is_array( $filters ) ){
            foreach( $filters as $filter => & $d ){
                add_filter( $filter , $d );
            }
        }
    }

    /* INIT ACTIONS */
    static function init_actions()
    {
        $actions = self::cfg( 'actions' );
        if( !empty( $actions ) && is_array( $actions ) ){
            foreach( $actions as $action => & $d ){
                add_action( $action , $d );
            }
        }
    }

    /* INIT SCRIPTS */
    static function init_scripts()
    {
        wp_enqueue_script( 'jquery' );

        wp_enqueue_script( 'functions' , get_template_directory_uri() . '/media/js/bootstrap.min.js' );
        wp_enqueue_script( 'settings' , get_template_directory_uri() . '/media/js/settings.js' );
        wp_enqueue_script( 'likes' , get_template_directory_uri() . '/media/js/likes.js' );
        wp_enqueue_script( 'jcanvas' , get_template_directory_uri() . '/media/js/jcanvas.min.js' );

        wp_enqueue_script(
            'js-pretty-photo',
            get_template_directory_uri( ) . '/media/js/jquery.prettyPhoto.js'
        );

        wp_enqueue_script(
            'settings-pretty-photo',
            get_template_directory_uri( ) . '/media/js/settings.prettyPhoto.js'
        );

        wp_enqueue_style(
            'css-pretty-photo',
            get_template_directory_uri( ) . '/media/css/prettyPhoto.css'
        );

        /* INCLUDE FOR REPLY COMMENTS */
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
                wp_enqueue_script( 'comment-reply' );

        /* INCLUDE STYLE.CSS */
        wp_enqueue_style( 'mythemes-style', get_stylesheet_uri() );
    }

    /* REGISTER THEME MENUS */
    static function reg_menus( )
    {
        register_nav_menus( self::cfg( 'menus' ) );
    }

    /* REGISTER THEME SIDEBARS */
    static function reg_sidebars( )
    {
        $sidebars = self::cfg( 'sidebars' );

        if( !empty( $sidebars ) && is_array( $sidebars ) ){
            foreach( $sidebars as $sidebar ){
                register_sidebar( $sidebar );
            }
        }

        /* CUSTOM SIDEBARS */
        $custom = sett::get( self::cfg( 'custom-sidebars' ) );
        if( !empty( $custom ) && is_array( $custom ) ){
            foreach( $custom as $s ){
                $sidebars[0][ 'name' ] = $s;
                $sidebars[0][ 'id' ] = strtolower( str_replace( ' ' , '-' , $s ) );
                $sidebars[0][ 'description' ] = __( 'Additional custom sidebar' , 'myThemes' );
                register_sidebar( $sidebars[ 0 ] );
            }
        }
    }

    function sidebars()
    {
        $sidebars = array( 'main-sidebar' => __( 'Main sidebar' , 'myThemes' ) );
        $custom = sett::get( self::cfg( 'custom-sidebars' ) );
        if( !empty( $custom ) ){
            foreach( $custom as $s ){
                $sidebars[ strtolower( str_replace( ' ' , '-' , $s ) ) ] = $s;
            }
        }
        return $sidebars;
    }

    static function setup()
    {
        myThemes::install_theme();

        load_theme_textdomain( 'myThemes' );
        load_theme_textdomain( 'myThemes' , get_template_directory() . '/media/languages' );

        if ( function_exists( 'load_child_theme_textdomain' ) ){
            load_child_theme_textdomain( 'myThemes' );
        }
        add_editor_style();

        add_theme_support( 'custom-background', array(
                'default-color' => 'fafafa',
                'default-image' => ''
        ) );

        add_theme_support( 'automatic-feed-links' );

        add_theme_support( 'post-thumbnails' );
        set_post_thumbnail_size( 1200, 9999 );
        
        add_filter( 'wp_head' , array( 'myThemes' , 'custom_style' ) );
    }

    static function install_theme()
    {
        $installed = myThemes::get( "db-likes-ver" );

        if( setup::$version != $installed ){
            setup::likes();
            sett::set( "db-likes-ver" , setup::$version );
        }
    }

    static function custom_style()
    {
?>
        <style type="text/css">
            <?php if( myThemes::get( 'logo' ) ) { ?>

                .navbar hgroup.brand{

                    margin-top: <?php echo myThemes::get( 'logo-top' ); ?>px;
                    <?php
                        $left = (int)myThemes::get( 'logo-left' );
                        if( $left > 0 ){
                            ?> margin-left: <?php echo $left; ?>px; <?php
                        }
                    ?>

                    <?php
                        if( myThemes::get( 'logo-top' ) < 0 ){
                            ?> margin-bottom: <?php echo (-1) * (int)myThemes::get( 'logo-top' ); ?>px;<?php
                        }

                        if( myThemes::get( 'logo-left' ) < 0 ){
                            ?> margin-right: <?php echo (-1) * (int)myThemes::get( 'logo-left' ); ?>px;<?php
                        }
                    ?>
                }

            <?php } ?>
            <?php
                $logo_color = myThemes::get( 'logo-color' );
                $logo_hover = myThemes::get( 'logo-hover' );

                $header_first = myThemes::get( 'header-first' );
                $header_second = myThemes::get( 'header-second' );
                $header_text = myThemes::get( 'header-text' );

                $menu_color = myThemes::get( 'menu-color' );
                $menu_hover = myThemes::get( 'menu-hover' );

                $link_color = myThemes::get( 'link-color' );
                $link_hover = myThemes::get( 'link-hover' );

                $footer_bkg = myThemes::get( 'footer-bkg' );
                $footer_border = myThemes::get( 'footer-border' );
                $footer_text = myThemes::get( 'footer-color' );
            ?>
            .navbar .brand h1 a,
            .navbar .brand h2 a{
                color: <?php echo $logo_color; ?>;
            }
            .navbar .brand h1 a:hover,
            .navbar .brand h2 a:hover{
                color: <?php echo $logo_hover; ?>;
            }
            
            .navbar .navbar-inner{
                background: <?php echo $header_first; ?>;
            }
            .search-bar{
                background: <?php echo $header_second; ?>;
            }
            .navbar .navbar-inner .nav-collapse.in.collapse{
                border-top: 1px solid <?php echo $header_second; ?>;
            }
            .navbar hgroup.brand p a{
                color: <?php echo $header_text; ?>;
            }
            
            
            .navbar .nav li a{
                color: <?php echo $menu_color ?>;
            }
            @media ( min-width: 980px ){
                .navbar nav.nav > ul ul > li:first-child > a,
                .navbar nav.nav div > ul ul > li:first-child > a{
                    border-top: 3px solid <?php echo $menu_hover ?>;
                }
            }
            .navbar nav.nav > ul li:hover > a,
            .navbar nav.nav div > ul li:hover > a{
                color: <?php echo $menu_hover ?>;
            }
            .navbar nav.nav > ul > li > ul canvas,
            .navbar nav.nav div > ul > li > ul canvas{
                color: <?php echo $menu_hover ?>;
            }
            button.btn.btn-navbar span.icon-bar{
                background: <?php echo $menu_color; ?>;
            }
            button.btn.btn-navbar:hover span.icon-bar{
                background: <?php echo $menu_hover ?>;
            }
            
            
            a{
                color: <?php echo $link_color; ?>;
            }
            a:hover{
                color: <?php echo $link_hover; ?>;
            }
            
            div.pagination.comments nav a.prev,
            div.pagination.comments nav a.next,
            input[type="submit"],
            input[type="button"],
            button.button,
            input.button,
            a.button,
            div.pagination ul li a,

            p.form-submit input[type="submit"]:hover,
            input[type="submit"].red:hover,
            input[type="button"].red:hover,
            button.button.red:hover,
            input.button.red:hover,
            a.button.red:hover,
            div.post-meta-tags a:hover{
                background-color: <?php echo $link_color; ?>;
            }
            
            div.pagination.comments nav a.prev:hover,
            div.pagination.comments nav a.next:hover,
            input[type="submit"]:hover,
            input[type="button"]:hover,
            button.button:hover,
            input.button:hover,
            a.button:hover,
            div.pagination ul li a:hover,

            p.form-submit input[type="submit"],
            div.pagination ul > li span.current,
            input[type="submit"].red,
            input[type="button"].red,
            button.button.red,
            input.button.red,
            a.button.red,
            div.post-meta-tags a{
                background-color: <?php echo $link_hover; ?>;
                color: #ffffff;
            }
            
            footer{
                background: <?php echo $footer_bkg; ?>;
            }
            footer div.social{
                border-bottom: 1px solid <?php echo $footer_border; ?>;
            }
            footer p{
                color: <?php echo $footer_text; ?>;
            }
            
            <?php echo myThemes::get( 'css' ); ?>
        </style>
<?php
    }

    static function user_contact( $user_contact )
    {
        $user_contact['vimeo']       = __( 'Vimeo profile ( url )' , 'myThemes' );  
        $user_contact['twitter']     = __( 'Twitter profile ( url )' , 'myThemes' );
        $user_contact['facebook']    = __( 'Facebook page or profile ( url )' , 'myThemes' );
        $user_contact['google_plus'] = __( 'Google + profile ( url )' , 'myThemes' );
        $user_contact['youtube']     = __( 'Youtube profile ( url )' , 'myThemes' );

        return $user_contact;  
    }

    function rssThumbnail( $content )
    {
        global $post;
        if ( has_post_thumbnail( $post->ID ) ){
            $content = '' . get_the_post_thumbnail( $post -> ID, 'small-thumb' , array( 'style' => 'float:left; margin:0 15px 15px 0;' ) ) . '' . $content;
        }
        return $content;
    }

    static function gravatar( $authorID , $size, $default = '' )
    {
        if( get_user_meta( $authorID , 'avatar' , true ) == -1 ){
            $result = '<img src="' . $default . '" height="' . $size . '" width="' . $size . '" alt="" class="photo avatar" />';
        }else{
            if(  get_user_meta( $authorID , 'avatar' , true ) > 0 ){
                $avatar_info = wp_get_attachment_image_src( get_user_meta( $authorID , 'avatar' , true ) , array( $size , $size ) );
                $result = '<img src="' . $avatar_info[0] . '" height="' . $size . '" width="' . $size . '" alt="" class="photo avatar" />';
            }else{
                $result = get_avatar( $authorID , $size , $default );
            }
        }

        return $result;
    }

    static function comment( $comment, $args, $depth )
    {
        $GLOBALS['comment'] = $comment;
        switch ( $comment -> comment_type ) {
            case '' : {
                echo '<li '; comment_class(); echo' id="li-comment-'; comment_ID(); echo '">';
                echo '<div id="comment-'; comment_ID(); echo '" class="comment-box">';
                echo '<div class="avatar">';
                echo myThemes::gravatar( $comment -> comment_author_email , 150 );
                echo '</div>';
                echo '<div class="comment-body pull-right">';
                echo '<div class="comment-content">';
                echo '<header>';
                echo '<cite>';
                echo get_comment_author_link( $comment -> comment_ID );
                echo '</cite>';

                echo '<span class="comment-meta">';
                echo '<time class="comment-time"><i class="icon-date"></i> ';
                printf( '%1$s ' , get_comment_date() );
                echo '</time>';
                comment_reply_link( array_merge( $args , array( 
                    'reply_text' => __( 'Reply', 'myThemes' ),
                    'before' => '<span class="comment-replay">',
                    'after' => '</span>',
                    'depth' => $depth,
                    'max_depth' => $args['max_depth'] )
                ) );
                echo '</span>';
                echo '<div class="clearfix"></div>';
                echo '</header>';

                echo '<p class="comment-quote">';
                if ( $comment -> comment_approved == '0' ) {
                    echo '<em class="comment-awaiting-moderation">';
                    _e( 'Your comment is awaiting moderation.' , 'myThemes' );
                    echo '</em>';
                }
                echo get_comment_text();            
                echo '</p>';

                echo '</div>';
                echo '</div>';
                echo '</div>';
                echo '<div class="clearfix"></div>';
                echo '</li>';
                break;
            }
            case 'trackback' :
            case 'pingback'  :{
                echo '<li '; comment_class(); echo' id="li-comment-'; comment_ID(); echo '">';
                echo '<div id="comment-'; comment_ID(); echo '" class="comment-box">';
                echo '<div class="comment-body pull-right">';
                echo '<div class="comment-content">';
                echo '<header>';
                echo '<cite>';
                echo get_comment_author_link( $comment -> comment_ID );
                echo '</cite>';

                echo '<span class="comment-meta">';
                echo '<time class="comment-time"><i class="icon-date"></i> ';
                printf( '%1$s ' , get_comment_date() );
                echo '</time>';
                echo '</span>';
                echo '<div class="clearfix"></div>';
                echo '</header>';

                echo '<p class="comment-quote">';
                if ( $comment -> comment_approved == '0' ) {
                    echo '<em class="comment-awaiting-moderation">';
                    _e( 'Your comment is awaiting moderation.' , 'myThemes' );
                    echo '</em>';
                }
                echo get_comment_text();            
                echo '</p>';

                echo '</div>';
                echo '</div>';
                echo '</div>';
                echo '<div class="clearfix"></div>';
                echo '</li>';
                break;
            }
        }
    }

    /* RETURN NUMBER OFF CURRENT BLOG PAGE */
    static function pagination()
    {
        global $wp_query;
        if( (int) get_query_var('paged') > 0 ){
            $paged = get_query_var('paged');
        }else{
            if( (int) get_query_var('page') > 0 ){
                $paged = get_query_var('page');
            }else{
                $paged = 1;
            }
        }

        return $paged;
    }

    /* DISPLAY BLOG TITLE */
    static function title( $title, $sep )
    {
        global $paged, $page;

        if ( is_feed() )
            return $title;

        /*/ Add the site name. */
        $title .= get_bloginfo( 'name' );

        /*/ Add the site description for the home/front page. */
        $site_description = get_bloginfo( 'description', 'display' );
        if ( $site_description && ( is_home() || is_front_page() ) )
            $title = "$title $sep $site_description";

        /*/ Add a page number if necessary. */
        if ( $paged >= 2 || $page >= 2 )
            $title = "$title $sep " . sprintf( __( 'Page %s', 'myThemes' ), max( $paged, $page ) );

        return $title;
    }

    static function favicon( $settings = 'favicon' )
    {
        if( myThemes::get( $settings ) ){
            echo '<link rel="shortcut icon" href="' . myThemes::get( $settings ) . '"/>';
        }
        else{
            if( file_exists(  get_template_directory() . '/favicon.ico' ) )
                echo '<link rel="shortcut icon" href="' . get_template_directory_uri() . '/favicon.ico"/>';
        }
    }

    static function ajaxurl()
    {
        echo '<script>';
        echo "var ajaxurl = '" . admin_url( '/admin-ajax.php' ) . "'";
        echo '</script>';
    }

    static function group()
    {
        return "myThemes";
    }

    static function name()
    {
        $theme = wp_get_theme();
        return $theme -> title;
    }

    static function version()
    {
        $theme = wp_get_theme();
        return $theme -> version;
    }
}
?>